@@ -38,7 +38,6 @@ References
 .. [1] Ding, Zejin, "Diversified Ensemble Classifiers for Highly
    Imbalanced Data Learning and their Application in Bioinformatics."
    Dissertation, Georgia State University, (2011).
-
 """
 
 # Author: Guillaume Lemaitre
@@ -59,10 +58,7 @@ from sklearn.utils import check_random_state
 
 from ..utils._validation import _deprecate_positional_args
 
-URL = (
-    "https://zenodo.org/record/61452/files/"
-    "benchmark-imbalanced-learn.tar.gz"
-)
+URL = "https://zenodo.org/record/61452/files/benchmark-imbalanced-learn.tar.gz"
 PRE_FILENAME = "x"
 POST_FILENAME = "data.npz"
 
@@ -115,45 +111,47 @@ def fetch_datasets(
 ):
     """Load the benchmark datasets from Zenodo, downloading it if necessary.
 
+    .. versionadded:: 0.3
+
     Parameters
     ----------
-    data_home : string, optional (default=None)
+    data_home : str, default=None
         Specify another download and cache folder for the datasets. By default
         all scikit-learn data is stored in '~/scikit_learn_data' subfolders.
 
-    filter_data : tuple of str/int or None, optional (default=None)
+    filter_data : tuple of str/int, default=None
         A tuple containing the ID or the name of the datasets to be returned.
         Refer to the above table to get the ID and name of the datasets.
 
-    download_if_missing : boolean, optional (default=True)
+    download_if_missing : bool, default=True
         If False, raise a IOError if the data is not locally available
         instead of trying to download the data from the source site.
 
-    random_state : int, RandomState instance or None, optional (default=None)
+    random_state : int, RandomState instance or None, default=None
         Random state for shuffling the dataset.
         If int, random_state is the seed used by the random number generator;
         If RandomState instance, random_state is the random number generator;
         If None, the random number generator is the RandomState instance used
         by `np.random`.
 
-    shuffle : bool, optional (default=False)
+    shuffle : bool, default=False
         Whether to shuffle dataset.
 
-    verbose : bool, optional (default=False)
+    verbose : bool, default=False
         Show information regarding the fetching.
 
     Returns
     -------
     datasets : OrderedDict of Bunch object,
         The ordered is defined by ``filter_data``. Each Bunch object ---
-        refered as dataset --- have the following attributes:
+        referred as dataset --- have the following attributes:
 
-    dataset.data : ndarray, shape (n_samples, n_features)
+        dataset.data : ndarray of shape (n_samples, n_features)
 
-    dataset.target : ndarray, shape (n_samples, )
+        dataset.target : ndarray of shape (n_samples,)
 
-    dataset.DESCR : string
-        Description of the each dataset.
+        dataset.DESCR : str
+            Description of the each dataset.
 
     Notes
     -----
@@ -239,17 +237,17 @@ def fetch_datasets(
             if isinstance(it, str):
                 if it not in list_data:
                     raise ValueError(
-                        "{} is not a dataset available. "
-                        "The available datasets are {}".format(it, list_data)
+                        f"{it} is not a dataset available. "
+                        f"The available datasets are {list_data}"
                     )
                 else:
                     filter_data_.append(it)
             elif isinstance(it, int):
                 if it < 1 or it > 27:
                     raise ValueError(
-                        "The dataset with the ID={} is not an "
-                        "available dataset. The IDs are "
-                        "{}".format(it, range(1, 28))
+                        f"The dataset with the ID={it} is not an "
+                        f"available dataset. The IDs are "
+                        f"{range(1, 28)}"
                     )
                 else:
                     # The index start at one, then we need to remove one
@@ -257,8 +255,8 @@ def fetch_datasets(
                     filter_data_.append(MAP_ID_NAME[it])
             else:
                 raise ValueError(
-                    "The value in the tuple should be str or int."
-                    " Got {} instead.".format(type(it))
+                    f"The value in the tuple should be str or int."
+                    f" Got {type(it)} instead."
                 )
 
     # go through the list and check if the data are available
