@@ -37,12 +37,14 @@ class EasyEnsembleClassifier(BaggingClassifier):
 
     Read more in the :ref:`User Guide <boosting>`.
 
+    .. versionadded:: 0.4
+
     Parameters
     ----------
     n_estimators : int, default=10
         Number of AdaBoost learners in the ensemble.
 
-    base_estimator : object, default=AdaBoostClassifier()
+    base_estimator : estimator object, default=AdaBoostClassifier()
         The base AdaBoost classifier used in the inner ensemble. Note that you
         can set the number of inner learner by passing your own instance.
 
@@ -60,7 +62,7 @@ class EasyEnsembleClassifier(BaggingClassifier):
 
     {random_state}
 
-    verbose : int, optional (default=0)
+    verbose : int, default=0
         Controls the verbosity of the building process.
 
     Attributes
@@ -71,12 +73,37 @@ class EasyEnsembleClassifier(BaggingClassifier):
     estimators_ : list of estimators
         The collection of fitted base estimators.
 
+    estimators_samples_ : list of arrays
+        The subset of drawn samples for each base estimator.
+
+    estimators_features_ : list of arrays
+        The subset of drawn features for each base estimator.
+
     classes_ : array, shape (n_classes,)
         The classes labels.
 
     n_classes_ : int or list
         The number of classes.
 
+    n_features_ : int
+        The number of features when ``fit`` is performed.
+
+        .. deprecated:: 1.0
+           `n_features_` is deprecated in `scikit-learn` 1.0 and will be removed
+           in version 1.2. Depending of the version of `scikit-learn` installed,
+           you will get be warned or not.
+
+    n_features_in_ : int
+        Number of features in the input dataset.
+
+        .. versionadded:: 0.9
+
+    feature_names_in_ : ndarray of shape (n_features_in_,)
+        Names of features seen during `fit`. Defined only when `X` has feature
+        names that are all strings.
+
+        .. versionadded:: 0.9
+
     See Also
     --------
     BalancedBaggingClassifier : Bagging classifier for which each base
@@ -103,7 +130,6 @@ class EasyEnsembleClassifier(BaggingClassifier):
 
     Examples
     --------
-
     >>> from collections import Counter
     >>> from sklearn.datasets import make_classification
     >>> from sklearn.model_selection import train_test_split
@@ -161,7 +187,9 @@ EasyEnsembleClassifier # doctest: +NORMALIZE_WHITESPACE
             self._sampling_strategy = {
                 np.where(self.classes_ == key)[0][0]: value
                 for key, value in check_sampling_strategy(
-                    self.sampling_strategy, y, 'under-sampling',
+                    self.sampling_strategy,
+                    y,
+                    "under-sampling",
                 ).items()
             }
         else:
@@ -173,14 +201,12 @@ EasyEnsembleClassifier # doctest: +NORMALIZE_WHITESPACE
         `base_estimator_` attribute."""
         if not isinstance(self.n_estimators, (numbers.Integral, np.integer)):
             raise ValueError(
-                "n_estimators must be an integer, "
-                "got {}.".format(type(self.n_estimators))
+                f"n_estimators must be an integer, " f"got {type(self.n_estimators)}."
             )
 
         if self.n_estimators <= 0:
             raise ValueError(
-                "n_estimators must be greater than zero, "
-                "got {}.".format(self.n_estimators)
+                f"n_estimators must be greater than zero, " f"got {self.n_estimators}."
             )
 
         if self.base_estimator is not None:
@@ -202,22 +228,28 @@ EasyEnsembleClassifier # doctest: +NORMALIZE_WHITESPACE
         )
 
     def fit(self, X, y):
-        """Train the ensemble on the training set.
+        """Build a Bagging ensemble of estimators from the training set (X, y).
 
         Parameters
         ----------
         X : {array-like, sparse matrix} of shape (n_samples, n_features)
-            The training input samples.
+            The training input samples. Sparse matrices are accepted only if
+            they are supported by the base estimator.
 
         y : array-like of shape (n_samples,)
-            The target values.
+            The target values (class labels in classification, real numbers in
+            regression).
 
         Returns
         -------
         self : object
-            Returns self.
+            Fitted estimator.
         """
+        # overwrite the base class method by disallowing `sample_weight`
+        return super().fit(X, y)
+
+    def _fit(self, X, y, max_samples=None, max_depth=None, sample_weight=None):
         check_target_type(y)
         # RandomUnderSampler is not supporting sample_weight. We need to pass
         # None.
-        return self._fit(X, y, self.max_samples, sample_weight=None)
+        return super()._fit(X, y, self.max_samples, sample_weight=None)
