@@ -25,6 +25,7 @@ from sklearn.tree import DecisionTreeClassifier
 from sklearn.utils import check_array
 from sklearn.utils import check_random_state
 from sklearn.utils import _safe_indexing
+from sklearn.utils.fixes import _joblib_parallel_args
 from sklearn.utils.validation import _check_sample_weight
 
 from ..pipeline import make_pipeline
@@ -50,7 +51,7 @@ def _local_parallel_build_trees(
     n_trees,
     verbose=0,
     class_weight=None,
-    n_samples_bootstrap=None
+    n_samples_bootstrap=None,
 ):
     # resample before to fit the tree
     X_resampled, y_resampled = sampler.fit_resample(X, y)
@@ -86,12 +87,14 @@ class BalancedRandomForestClassifier(RandomForestClassifier):
 
     Read more in the :ref:`User Guide <forest>`.
 
+    .. versionadded:: 0.4
+
     Parameters
     ----------
     n_estimators : int, default=100
         The number of trees in the forest.
 
-    criterion : str, default="gini"
+    criterion : {{"gini", "entropy"}}, default="gini"
         The function to measure the quality of a split. Supported criteria are
         "gini" for the Gini impurity and "entropy" for the information gain.
         Note: this parameter is tree-specific.
@@ -101,7 +104,7 @@ class BalancedRandomForestClassifier(RandomForestClassifier):
         all leaves are pure or until all leaves contain less than
         min_samples_split samples.
 
-    min_samples_split : int, float, default=2
+    min_samples_split : int or float, default=2
         The minimum number of samples required to split an internal node:
 
         - If int, then consider `min_samples_split` as the minimum number.
@@ -109,7 +112,7 @@ class BalancedRandomForestClassifier(RandomForestClassifier):
           `ceil(min_samples_split * n_samples)` are the minimum
           number of samples for each split.
 
-    min_samples_leaf : int, float, default=1
+    min_samples_leaf : int or float, default=1
         The minimum number of samples required to be at a leaf node:
 
         - If int, then consider ``min_samples_leaf`` as the minimum number.
@@ -228,10 +231,17 @@ class BalancedRandomForestClassifier(RandomForestClassifier):
 
     Attributes
     ----------
-    estimators_ : list of DecisionTreeClassifier
+    base_estimator_ : :class:`~sklearn.tree.DecisionTreeClassifier` instance
+        The child estimator template used to create the collection of fitted
+        sub-estimators.
+
+    estimators_ : list of :class:`~sklearn.tree.DecisionTreeClassifier`
         The collection of fitted sub-estimators.
 
-    samplers_ : list of RandomUnderSampler
+    base_sampler_ : :class:`~imblearn.under_sampling.RandomUnderSampler`
+        The base sampler used to construct the subsequent list of samplers.
+
+    samplers_ : list of :class:`~imblearn.under_sampling.RandomUnderSampler`
         The collection of fitted samplers.
 
     pipelines_ : list of Pipeline.
@@ -248,6 +258,22 @@ class BalancedRandomForestClassifier(RandomForestClassifier):
     n_features_ : int
         The number of features when ``fit`` is performed.
 
+        .. deprecated:: 1.0
+           `n_features_` is deprecated in `scikit-learn` 1.0 and will be removed
+           in version 1.2. Depending of the version of `scikit-learn` installed,
+           you will get be warned or not.
+
+    n_features_in_ : int
+        Number of features in the input dataset.
+
+        .. versionadded:: 0.9
+
+    feature_names_in_ : ndarray of shape (n_features_in_,)
+        Names of features seen during `fit`. Defined only when `X` has feature
+        names that are all strings.
+
+        .. versionadded:: 0.9
+
     n_outputs_ : int
         The number of outputs when ``fit`` is performed.
 
@@ -352,14 +378,12 @@ class BalancedRandomForestClassifier(RandomForestClassifier):
         `base_estimator_` attribute."""
         if not isinstance(self.n_estimators, (numbers.Integral, np.integer)):
             raise ValueError(
-                "n_estimators must be an integer, "
-                "got {}.".format(type(self.n_estimators))
+                f"n_estimators must be an integer, " f"got {type(self.n_estimators)}."
             )
 
         if self.n_estimators <= 0:
             raise ValueError(
-                "n_estimators must be greater than zero, "
-                "got {}.".format(self.n_estimators)
+                f"n_estimators must be greater than zero, " f"got {self.n_estimators}."
             )
 
         if self.base_estimator is not None:
@@ -378,9 +402,7 @@ class BalancedRandomForestClassifier(RandomForestClassifier):
         sub-estimators.
         """
         estimator = clone(self.base_estimator_)
-        estimator.set_params(
-            **{p: getattr(self, p) for p in self.estimator_params}
-        )
+        estimator.set_params(**{p: getattr(self, p) for p in self.estimator_params})
         sampler = clone(self.base_sampler_)
 
         if random_state is not None:
@@ -418,22 +440,19 @@ class BalancedRandomForestClassifier(RandomForestClassifier):
 
         # Validate or convert input data
         if issparse(y):
-            raise ValueError(
-                "sparse multilabel-indicator for y is not supported."
-            )
-        X, y = self._validate_data(X, y, multi_output=True,
-                                   accept_sparse="csc", dtype=DTYPE)
+            raise ValueError("sparse multilabel-indicator for y is not supported.")
+        X, y = self._validate_data(
+            X, y, multi_output=True, accept_sparse="csc", dtype=DTYPE
+        )
         if sample_weight is not None:
             sample_weight = _check_sample_weight(sample_weight, X)
+        self._n_features = X.shape[1]
 
         if issparse(X):
             # Pre-sort indices to avoid that each individual tree of the
             # ensemble sorts the indices.
             X.sort_indices()
 
-        # Remap output
-        _, self.n_features_ = X.shape
-
         y = np.atleast_1d(y)
         if y.ndim == 2 and y.shape[1] == 1:
             warn(
@@ -460,7 +479,9 @@ class BalancedRandomForestClassifier(RandomForestClassifier):
             self._sampling_strategy = {
                 np.where(self.classes_[0] == key)[0][0]: value
                 for key, value in check_sampling_strategy(
-                    self.sampling_strategy, y, 'under-sampling',
+                    self.sampling_strategy,
+                    y,
+                    "under-sampling",
                 ).items()
             }
         else:
@@ -474,17 +495,14 @@ class BalancedRandomForestClassifier(RandomForestClassifier):
 
         # Get bootstrap sample size
         n_samples_bootstrap = _get_n_samples_bootstrap(
-            n_samples=X.shape[0],
-            max_samples=self.max_samples
+            n_samples=X.shape[0], max_samples=self.max_samples
         )
 
         # Check parameters
         self._validate_estimator()
 
         if not self.bootstrap and self.oob_score:
-            raise ValueError(
-                "Out of bag estimation only available" " if bootstrap=True"
-            )
+            raise ValueError("Out of bag estimation only available if bootstrap=True")
 
         random_state = check_random_state(self.random_state)
 
@@ -517,9 +535,7 @@ class BalancedRandomForestClassifier(RandomForestClassifier):
             trees = []
             samplers = []
             for _ in range(n_more_estimators):
-                tree, sampler = self._make_sampler_estimator(
-                    random_state=random_state
-                )
+                tree, sampler = self._make_sampler_estimator(random_state=random_state)
                 trees.append(tree)
                 samplers.append(sampler)
 
@@ -530,7 +546,9 @@ class BalancedRandomForestClassifier(RandomForestClassifier):
             # at a higher level, since correctness does not rely on using
             # threads.
             samplers_trees = Parallel(
-                n_jobs=self.n_jobs, verbose=self.verbose, prefer="threads"
+                n_jobs=self.n_jobs,
+                verbose=self.verbose,
+                **_joblib_parallel_args(prefer="threads"),
             )(
                 delayed(_local_parallel_build_trees)(
                     s,
@@ -573,15 +591,16 @@ class BalancedRandomForestClassifier(RandomForestClassifier):
 
     def _set_oob_score(self, X, y):
         """Compute out-of-bag score."""
-        X = check_array(X, dtype=DTYPE, accept_sparse='csr')
+        X = check_array(X, dtype=DTYPE, accept_sparse="csr")
 
         n_classes_ = self.n_classes_
         n_samples = y.shape[0]
 
         oob_decision_function = []
         oob_score = 0.0
-        predictions = [np.zeros((n_samples, n_classes_[k]))
-                       for k in range(self.n_outputs_)]
+        predictions = [
+            np.zeros((n_samples, n_classes_[k])) for k in range(self.n_outputs_)
+        ]
 
         for sampler, estimator in zip(self.samplers_, self.estimators_):
             X_resample = X[sampler.sample_indices_]
@@ -608,21 +627,22 @@ class BalancedRandomForestClassifier(RandomForestClassifier):
 
         for k in range(self.n_outputs_):
             if (predictions[k].sum(axis=1) == 0).any():
-                warn("Some inputs do not have OOB scores. "
-                     "This probably means too few trees were used "
-                     "to compute any reliable oob estimates.")
+                warn(
+                    "Some inputs do not have OOB scores. "
+                    "This probably means too few trees were used "
+                    "to compute any reliable oob estimates."
+                )
 
             with np.errstate(invalid="ignore", divide="ignore"):
                 # with the resampling, we are likely to have rows not included
                 # for the OOB score leading to division by zero
-                decision = (predictions[k] /
-                            predictions[k].sum(axis=1)[:, np.newaxis])
+                decision = predictions[k] / predictions[k].sum(axis=1)[:, np.newaxis]
             mask_scores = np.isnan(np.sum(decision, axis=1))
             oob_decision_function.append(decision)
             oob_score += np.mean(
-                y[~mask_scores, k] == np.argmax(predictions[k][~mask_scores],
-                                                axis=1),
-                axis=0)
+                y[~mask_scores, k] == np.argmax(predictions[k][~mask_scores], axis=1),
+                axis=0,
+            )
 
         if self.n_outputs_ == 1:
             self.oob_decision_function_ = oob_decision_function[0]
@@ -631,5 +651,13 @@ class BalancedRandomForestClassifier(RandomForestClassifier):
 
         self.oob_score_ = oob_score / self.n_outputs_
 
+    @property
+    def n_features_(self):
+        """Number of features when fitting the estimator."""
+        return getattr(self.n_features_in_, "n_features_", self._n_features)
+
     def _more_tags(self):
-        return {"multioutput": False}
+        return {
+            "multioutput": False,
+            "multilabel": False,
+        }
