@@ -63,10 +63,16 @@ class Pipeline(pipeline.Pipeline):
 
     Attributes
     ----------
-    named_steps : bunch object, a dictionary with attribute access
+    named_steps : :class:`~sklearn.utils.Bunch`
         Read-only attribute to access any step parameter by user given name.
         Keys are step names and values are steps parameters.
 
+    classes_ : ndarray of shape (n_classes,)
+        The classes labels.
+
+    n_features_in_ : int
+        Number of features seen during first step `fit` method.
+
     See Also
     --------
     make_pipeline : Helper function to make pipeline.
@@ -88,7 +94,7 @@ class Pipeline(pipeline.Pipeline):
     >>> X, y = make_classification(n_classes=2, class_sep=2,
     ... weights=[0.1, 0.9], n_informative=3, n_redundant=1, flip_y=0,
     ... n_features=20, n_clusters_per_class=1, n_samples=1000, random_state=10)
-    >>> print('Original dataset shape {}'.format(Counter(y)))
+    >>> print(f'Original dataset shape {Counter(y)}')
     Original dataset shape Counter({1: 900, 0: 100})
     >>> pca = PCA()
     >>> smt = SMOTE(random_state=42)
@@ -149,8 +155,7 @@ class Pipeline(pipeline.Pipeline):
 
             if isinstance(t, pipeline.Pipeline):
                 raise TypeError(
-                    "All intermediate steps of the chain should not be"
-                    " Pipelines"
+                    "All intermediate steps of the chain should not be Pipelines"
                 )
 
         # We allow last estimator to be None as an identity transformation
@@ -165,9 +170,7 @@ class Pipeline(pipeline.Pipeline):
                 % (estimator, type(estimator))
             )
 
-    def _iter(
-        self, with_final=True, filter_passthrough=True, filter_resample=True
-    ):
+    def _iter(self, with_final=True, filter_passthrough=True, filter_resample=True):
         """Generate (idx, (name, trans)) tuples from self.steps.
 
         When `filter_passthrough` is `True`, 'passthrough' and None
@@ -182,7 +185,7 @@ class Pipeline(pipeline.Pipeline):
 
     # Estimator interface
 
-    def _fit(self, X, y=None, **fit_params):
+    def _fit(self, X, y=None, **fit_params_steps):
         self.steps = list(self.steps)
         self._validate_steps()
         # Setup the memory
@@ -191,27 +194,11 @@ class Pipeline(pipeline.Pipeline):
         fit_transform_one_cached = memory.cache(pipeline._fit_transform_one)
         fit_resample_one_cached = memory.cache(_fit_resample_one)
 
-        fit_params_steps = {
-            name: {} for name, step in self.steps if step is not None
-        }
-        for pname, pval in fit_params.items():
-            if '__' not in pname:
-                raise ValueError(
-                    "Pipeline.fit does not accept the {} parameter. "
-                    "You can pass parameters to specific steps of your "
-                    "pipeline using the stepname__parameter format, e.g. "
-                    "`Pipeline.fit(X, y, logisticregression__sample_weight"
-                    "=sample_weight)`.".format(pname))
-            step, param = pname.split("__", 1)
-            fit_params_steps[step][param] = pval
-        for (step_idx,
-             name,
-             transformer) in self._iter(with_final=False,
-                                        filter_passthrough=False,
-                                        filter_resample=False):
-            if (transformer is None or transformer == 'passthrough'):
-                with _print_elapsed_time('Pipeline',
-                                         self._log_message(step_idx)):
+        for (step_idx, name, transformer) in self._iter(
+            with_final=False, filter_passthrough=False, filter_resample=False
+        ):
+            if transformer is None or transformer == "passthrough":
+                with _print_elapsed_time("Pipeline", self._log_message(step_idx)):
                     continue
 
             try:
@@ -222,30 +209,33 @@ class Pipeline(pipeline.Pipeline):
             finally:
                 cloned_transformer = clone(transformer) if mem else transformer
 
-            # Fit or load from cache the current transfomer
+            # Fit or load from cache the current transformer
             if hasattr(cloned_transformer, "transform") or hasattr(
                 cloned_transformer, "fit_transform"
             ):
                 X, fitted_transformer = fit_transform_one_cached(
-                    cloned_transformer, X, y, None,
-                    message_clsname='Pipeline',
+                    cloned_transformer,
+                    X,
+                    y,
+                    None,
+                    message_clsname="Pipeline",
                     message=self._log_message(step_idx),
-                    **fit_params_steps[name]
+                    **fit_params_steps[name],
                 )
             elif hasattr(cloned_transformer, "fit_resample"):
                 X, y, fitted_transformer = fit_resample_one_cached(
-                    cloned_transformer, X, y,
-                    message_clsname='Pipeline',
+                    cloned_transformer,
+                    X,
+                    y,
+                    message_clsname="Pipeline",
                     message=self._log_message(step_idx),
-                    **fit_params_steps[name]
+                    **fit_params_steps[name],
                 )
             # Replace the transformer of the step with the fitted
             # transformer. This is necessary when loading the transformer
             # from the cache.
             self.steps[step_idx] = (name, fitted_transformer)
-        if self._final_estimator == "passthrough":
-            return X, y, {}
-        return X, y, fit_params_steps[self.steps[-1][0]]
+        return X, y
 
     def fit(self, X, y=None, **fit_params):
         """Fit the model.
@@ -274,11 +264,12 @@ class Pipeline(pipeline.Pipeline):
         self : Pipeline
             This estimator.
         """
-        Xt, yt, fit_params = self._fit(X, y, **fit_params)
-        with _print_elapsed_time('Pipeline',
-                                 self._log_message(len(self.steps) - 1)):
+        fit_params_steps = self._check_fit_params(**fit_params)
+        Xt, yt = self._fit(X, y, **fit_params_steps)
+        with _print_elapsed_time("Pipeline", self._log_message(len(self.steps) - 1)):
             if self._final_estimator != "passthrough":
-                self._final_estimator.fit(Xt, yt, **fit_params)
+                fit_params_last_step = fit_params_steps[self.steps[-1][0]]
+                self._final_estimator.fit(Xt, yt, **fit_params_last_step)
         return self
 
     def fit_transform(self, X, y=None, **fit_params):
@@ -308,16 +299,18 @@ class Pipeline(pipeline.Pipeline):
         Xt : array-like of shape (n_samples, n_transformed_features)
             Transformed samples.
         """
+        fit_params_steps = self._check_fit_params(**fit_params)
+        Xt, yt = self._fit(X, y, **fit_params_steps)
+
         last_step = self._final_estimator
-        Xt, yt, fit_params = self._fit(X, y, **fit_params)
-        with _print_elapsed_time('Pipeline',
-                                 self._log_message(len(self.steps) - 1)):
+        with _print_elapsed_time("Pipeline", self._log_message(len(self.steps) - 1)):
             if last_step == "passthrough":
                 return Xt
-            elif hasattr(last_step, "fit_transform"):
-                return last_step.fit_transform(Xt, yt, **fit_params)
+            fit_params_last_step = fit_params_steps[self.steps[-1][0]]
+            if hasattr(last_step, "fit_transform"):
+                return last_step.fit_transform(Xt, yt, **fit_params_last_step)
             else:
-                return last_step.fit(Xt, yt, **fit_params).transform(Xt)
+                return last_step.fit(Xt, yt, **fit_params_last_step).transform(Xt)
 
     def fit_resample(self, X, y=None, **fit_params):
         """Fit the model and sample with the final estimator.
@@ -349,14 +342,15 @@ class Pipeline(pipeline.Pipeline):
         yt : array-like of shape (n_samples, n_transformed_features)
             Transformed target.
         """
+        fit_params_steps = self._check_fit_params(**fit_params)
+        Xt, yt = self._fit(X, y, **fit_params_steps)
         last_step = self._final_estimator
-        Xt, yt, fit_params = self._fit(X, y, **fit_params)
-        with _print_elapsed_time('Pipeline',
-                                 self._log_message(len(self.steps) - 1)):
+        with _print_elapsed_time("Pipeline", self._log_message(len(self.steps) - 1)):
             if last_step == "passthrough":
                 return Xt
-            elif hasattr(last_step, "fit_resample"):
-                return last_step.fit_resample(Xt, yt, **fit_params)
+            fit_params_last_step = fit_params_steps[self.steps[-1][0]]
+            if hasattr(last_step, "fit_resample"):
+                return last_step.fit_resample(Xt, yt, **fit_params_last_step)
 
     @if_delegate_has_method(delegate="_final_estimator")
     def fit_predict(self, X, y=None, **fit_params):
@@ -386,26 +380,23 @@ class Pipeline(pipeline.Pipeline):
         y_pred : ndarray of shape (n_samples,)
             The predicted target.
         """
-        Xt, yt, fit_params = self._fit(X, y, **fit_params)
-        with _print_elapsed_time('Pipeline',
-                                 self._log_message(len(self.steps) - 1)):
-            y_pred = self.steps[-1][-1].fit_predict(Xt, yt, **fit_params)
+        fit_params_steps = self._check_fit_params(**fit_params)
+        Xt, yt = self._fit(X, y, **fit_params_steps)
+
+        fit_params_last_step = fit_params_steps[self.steps[-1][0]]
+        with _print_elapsed_time("Pipeline", self._log_message(len(self.steps) - 1)):
+            y_pred = self.steps[-1][-1].fit_predict(Xt, yt, **fit_params_last_step)
         return y_pred
 
 
-def _fit_resample_one(sampler,
-                      X,
-                      y,
-                      message_clsname='',
-                      message=None,
-                      **fit_params):
+def _fit_resample_one(sampler, X, y, message_clsname="", message=None, **fit_params):
     with _print_elapsed_time(message_clsname, message):
         X_res, y_res = sampler.fit_resample(X, y, **fit_params)
 
         return X_res, y_res, sampler
 
 
-def make_pipeline(*steps, **kwargs):
+def make_pipeline(*steps, memory=None, verbose=False):
     """Construct a Pipeline from the given estimators.
 
     This is a shorthand for the Pipeline constructor; it does not require, and
@@ -434,6 +425,7 @@ def make_pipeline(*steps, **kwargs):
     Returns
     -------
     p : Pipeline
+        Returns an imbalanced-learn `Pipeline` instance that handles samplers.
 
     See Also
     --------
@@ -449,12 +441,4 @@ def make_pipeline(*steps, **kwargs):
     Pipeline(steps=[('standardscaler', StandardScaler()),
                     ('gaussiannb', GaussianNB())])
     """
-    memory = kwargs.pop("memory", None)
-    verbose = kwargs.pop('verbose', False)
-    if kwargs:
-        raise TypeError(
-            'Unknown keyword arguments: "{}"'.format(list(kwargs.keys())[0])
-        )
-    return Pipeline(
-        pipeline._name_estimators(steps), memory=memory, verbose=verbose
-    )
+    return Pipeline(pipeline._name_estimators(steps), memory=memory, verbose=verbose)
