@@ -41,7 +41,7 @@ class EditedNearestNeighbours(BaseCleaningSampler):
     n_neighbors : int or object, default=3
         If ``int``, size of the neighbourhood to consider to compute the
         nearest neighbors. If object, an estimator that inherits from
-        :class:`sklearn.neighbors.base.KNeighborsMixin` that will be used to
+        :class:`~sklearn.neighbors.base.KNeighborsMixin` that will be used to
         find the nearest-neighbors.
 
     kind_sel : {{'all', 'mode'}}, default='all'
@@ -52,15 +52,31 @@ class EditedNearestNeighbours(BaseCleaningSampler):
         - If ``'mode'``, the majority vote of the neighbours will be used in
           order to exclude a sample.
 
+        The strategy `"all"` will be less conservative than `'mode'`. Thus,
+        more samples will be removed when `kind_sel="all"` generally.
+
     {n_jobs}
 
     Attributes
     ----------
-    sample_indices_ : ndarray of shape (n_new_samples)
+    sampling_strategy_ : dict
+        Dictionary containing the information to sample the dataset. The keys
+        corresponds to the class labels from which to sample and the values
+        are the number of samples to sample.
+
+    nn_ : estimator object
+        Validated K-nearest Neighbours instance created from `n_neighbors` parameter.
+
+    sample_indices_ : ndarray of shape (n_new_samples,)
         Indices of the samples selected.
 
         .. versionadded:: 0.4
 
+    n_features_in_ : int
+        Number of features in the input dataset.
+
+        .. versionadded:: 0.9
+
     See Also
     --------
     CondensedNearestNeighbour : Undersample by condensing samples.
@@ -102,8 +118,12 @@ EditedNearestNeighbours # doctest: +NORMALIZE_WHITESPACE
 
     @_deprecate_positional_args
     def __init__(
-        self, *, sampling_strategy="auto", n_neighbors=3, kind_sel="all",
-        n_jobs=None
+        self,
+        *,
+        sampling_strategy="auto",
+        n_neighbors=3,
+        kind_sel="all",
+        n_jobs=None,
     ):
         super().__init__(sampling_strategy=sampling_strategy)
         self.n_neighbors = n_neighbors
@@ -132,9 +152,7 @@ EditedNearestNeighbours # doctest: +NORMALIZE_WHITESPACE
                 target_class_indices = np.flatnonzero(y == target_class)
                 X_class = _safe_indexing(X, target_class_indices)
                 y_class = _safe_indexing(y, target_class_indices)
-                nnhood_idx = self.nn_.kneighbors(
-                    X_class, return_distance=False
-                )[:, 1:]
+                nnhood_idx = self.nn_.kneighbors(X_class, return_distance=False)[:, 1:]
                 nnhood_label = y[nnhood_idx]
                 if self.kind_sel == "mode":
                     nnhood_label, _ = mode(nnhood_label, axis=1)
@@ -180,7 +198,7 @@ class RepeatedEditedNearestNeighbours(BaseCleaningSampler):
     n_neighbors : int or object, default=3
         If ``int``, size of the neighbourhood to consider to compute the
         nearest neighbors. If object, an estimator that inherits from
-        :class:`sklearn.neighbors.base.KNeighborsMixin` that will be used to
+        :class:`~sklearn.neighbors.base.KNeighborsMixin` that will be used to
         find the nearest-neighbors.
 
     max_iter : int, default=100
@@ -195,11 +213,26 @@ class RepeatedEditedNearestNeighbours(BaseCleaningSampler):
         - If ``'mode'``, the majority vote of the neighbours will be used in
           order to exclude a sample.
 
+        The strategy `"all"` will be less conservative than `'mode'`. Thus,
+        more samples will be removed when `kind_sel="all"` generally.
+
     {n_jobs}
 
     Attributes
     ----------
-    sample_indices_ : ndarray of shape (n_new_samples)
+    sampling_strategy_ : dict
+        Dictionary containing the information to sample the dataset. The keys
+        corresponds to the class labels from which to sample and the values
+        are the number of samples to sample.
+
+    nn_ : estimator object
+        Validated K-nearest Neighbours estimator linked to the parameter `n_neighbors`.
+
+    enn_ : sampler object
+        The validated :class:`~imblearn.under_sampling.EditedNearestNeighbours`
+        instance.
+
+    sample_indices_ : ndarray of shape (n_new_samples,)
         Indices of the samples selected.
 
         .. versionadded:: 0.4
@@ -209,6 +242,11 @@ class RepeatedEditedNearestNeighbours(BaseCleaningSampler):
 
         .. versionadded:: 0.6
 
+    n_features_in_ : int
+        Number of features in the input dataset.
+
+        .. versionadded:: 0.9
+
     See Also
     --------
     CondensedNearestNeighbour : Undersample by condensing samples.
@@ -232,7 +270,6 @@ class RepeatedEditedNearestNeighbours(BaseCleaningSampler):
 
     Examples
     --------
-
     >>> from collections import Counter
     >>> from sklearn.datasets import make_classification
     >>> from imblearn.under_sampling import \
@@ -268,8 +305,8 @@ RepeatedEditedNearestNeighbours # doctest : +NORMALIZE_WHITESPACE
         """Private function to create the NN estimator"""
         if self.max_iter < 2:
             raise ValueError(
-                "max_iter must be greater than 1."
-                " Got {} instead.".format(type(self.max_iter))
+                f"max_iter must be greater than 1."
+                f" Got {type(self.max_iter)} instead."
             )
 
         self.nn_ = check_neighbors_object(
@@ -314,21 +351,23 @@ RepeatedEditedNearestNeighbours # doctest : +NORMALIZE_WHITESPACE
                     if key != class_minority
                 ]
             )
-            b_min_bec_maj = np.any(
-                count_non_min < target_stats[class_minority]
-            )
+            b_min_bec_maj = np.any(count_non_min < target_stats[class_minority])
 
             # Case 3
             b_remove_maj_class = len(stats_enn) < len(target_stats)
 
-            X_, y_, = X_enn, y_enn
-            self.sample_indices_ = self.sample_indices_[
-                self.enn_.sample_indices_
-            ]
+            X_, y_, = (
+                X_enn,
+                y_enn,
+            )
+            self.sample_indices_ = self.sample_indices_[self.enn_.sample_indices_]
 
             if b_conv or b_min_bec_maj or b_remove_maj_class:
                 if b_conv:
-                    X_, y_, = X_enn, y_enn
+                    X_, y_, = (
+                        X_enn,
+                        y_enn,
+                    )
                     self.sample_indices_ = self.sample_indices_[
                         self.enn_.sample_indices_
                     ]
@@ -359,11 +398,11 @@ class AllKNN(BaseCleaningSampler):
     ----------
     {sampling_strategy}
 
-    n_neighbors : int or object, default=3
+    n_neighbors : int or estimator object, default=3
         If ``int``, size of the neighbourhood to consider to compute the
         nearest neighbors. If object, an estimator that inherits from
-        :class:`sklearn.neighbors.base.KNeighborsMixin` that will be used to
-        find the nearest-neighbors.
+        :class:`~sklearn.neighbors.base.KNeighborsMixin` that will be used to
+        find the nearest-neighbors. By default, it will be a 3-NN.
 
     kind_sel : {{'all', 'mode'}}, default='all'
         Strategy to use in order to exclude samples.
@@ -373,6 +412,9 @@ class AllKNN(BaseCleaningSampler):
         - If ``'mode'``, the majority vote of the neighbours will be used in
           order to exclude a sample.
 
+        The strategy `"all"` will be less conservative than `'mode'`. Thus,
+        more samples will be removed when `kind_sel="all"` generally.
+
     allow_minority : bool, default=False
         If ``True``, it allows the majority classes to become the minority
         class without early stopping.
@@ -383,11 +425,28 @@ class AllKNN(BaseCleaningSampler):
 
     Attributes
     ----------
-    sample_indices_ : ndarray of shape (n_new_samples)
+    sampling_strategy_ : dict
+        Dictionary containing the information to sample the dataset. The keys
+        corresponds to the class labels from which to sample and the values
+        are the number of samples to sample.
+
+    nn_ : estimator object
+        Validated K-nearest Neighbours estimator linked to the parameter `n_neighbors`.
+
+    enn_ : sampler object
+        The validated :class:`~imblearn.under_sampling.EditedNearestNeighbours`
+        instance.
+
+    sample_indices_ : ndarray of shape (n_new_samples,)
         Indices of the samples selected.
 
         .. versionadded:: 0.4
 
+    n_features_in_ : int
+        Number of features in the input dataset.
+
+        .. versionadded:: 0.9
+
     See Also
     --------
     CondensedNearestNeighbour: Under-sampling by condensing samples.
@@ -411,7 +470,6 @@ class AllKNN(BaseCleaningSampler):
 
     Examples
     --------
-
     >>> from collections import Counter
     >>> from sklearn.datasets import make_classification
     >>> from imblearn.under_sampling import \
@@ -487,9 +545,7 @@ AllKNN # doctest: +NORMALIZE_WHITESPACE
                     if key != class_minority
                 ]
             )
-            b_min_bec_maj = np.any(
-                count_non_min < target_stats[class_minority]
-            )
+            b_min_bec_maj = np.any(count_non_min < target_stats[class_minority])
             if self.allow_minority:
                 # overwrite b_min_bec_maj
                 b_min_bec_maj = False
@@ -497,10 +553,11 @@ AllKNN # doctest: +NORMALIZE_WHITESPACE
             # Case 2
             b_remove_maj_class = len(stats_enn) < len(target_stats)
 
-            X_, y_, = X_enn, y_enn
-            self.sample_indices_ = self.sample_indices_[
-                self.enn_.sample_indices_
-            ]
+            X_, y_, = (
+                X_enn,
+                y_enn,
+            )
+            self.sample_indices_ = self.sample_indices_[self.enn_.sample_indices_]
 
             if b_min_bec_maj or b_remove_maj_class:
                 break
