@@ -37,13 +37,13 @@ class InstanceHardnessThreshold(BaseUnderSampler):
 
     Parameters
     ----------
-    estimator : object, default=None
+    estimator : estimator object, default=None
         Classifier to be used to estimate instance hardness of the samples.  By
-        default a :class:`sklearn.ensemble.RandomForestClassifier` will be used.
-        If ``str``, the choices using a string are the following: ``'knn'``,
-        ``'decision-tree'``, ``'random-forest'``, ``'adaboost'``,
+        default a :class:`~sklearn.ensemble.RandomForestClassifier` will be
+        used. If ``str``, the choices using a string are the following:
+        ``'knn'``, ``'decision-tree'``, ``'random-forest'``, ``'adaboost'``,
         ``'gradient-boosting'`` and ``'linear-svm'``.  If object, an estimator
-        inherited from :class:`sklearn.base.ClassifierMixin` and having an
+        inherited from :class:`~sklearn.base.ClassifierMixin` and having an
         attribute :func:`predict_proba`.
 
     {sampling_strategy}
@@ -57,11 +57,24 @@ class InstanceHardnessThreshold(BaseUnderSampler):
 
     Attributes
     ----------
-    sample_indices_ : ndarray of shape (n_new_samples)
+    sampling_strategy_ : dict
+        Dictionary containing the information to sample the dataset. The keys
+        corresponds to the class labels from which to sample and the values
+        are the number of samples to sample.
+
+    estimator_ : estimator object
+        The validated classifier used to estimate the instance hardness of the samples.
+
+    sample_indices_ : ndarray of shape (n_new_samples,)
         Indices of the samples selected.
 
         .. versionadded:: 0.4
 
+    n_features_in_ : int
+        Number of features in the input dataset.
+
+        .. versionadded:: 0.9
+
     See Also
     --------
     NearMiss : Undersample based on near-miss search.
@@ -83,7 +96,6 @@ class InstanceHardnessThreshold(BaseUnderSampler):
 
     Examples
     --------
-
     >>> from collections import Counter
     >>> from sklearn.datasets import make_classification
     >>> from imblearn.under_sampling import InstanceHardnessThreshold
@@ -133,9 +145,7 @@ class InstanceHardnessThreshold(BaseUnderSampler):
             )
         else:
             raise ValueError(
-                "Invalid parameter `estimator`. Got {}.".format(
-                    type(self.estimator)
-                )
+                f"Invalid parameter `estimator`. Got {type(self.estimator)}."
             )
 
     def _fit_resample(self, X, y):
@@ -144,11 +154,17 @@ class InstanceHardnessThreshold(BaseUnderSampler):
 
         target_stats = Counter(y)
         skf = StratifiedKFold(
-            n_splits=self.cv, shuffle=True, random_state=random_state,
+            n_splits=self.cv,
+            shuffle=True,
+            random_state=random_state,
         )
         probabilities = cross_val_predict(
-            self.estimator_, X, y, cv=skf, n_jobs=self.n_jobs,
-            method='predict_proba'
+            self.estimator_,
+            X,
+            y,
+            cv=skf,
+            n_jobs=self.n_jobs,
+            method="predict_proba",
         )
         probabilities = probabilities[range(len(y)), y]
 
