@@ -34,30 +34,45 @@ class NearMiss(BaseUnderSampler):
     version : int, default=1
         Version of the NearMiss to use. Possible values are 1, 2 or 3.
 
-    n_neighbors : int or object, default=3
+    n_neighbors : int or estimator object, default=3
         If ``int``, size of the neighbourhood to consider to compute the
         average distance to the minority point samples.  If object, an
         estimator that inherits from
-        :class:`sklearn.neighbors.base.KNeighborsMixin` that will be used to
+        :class:`~sklearn.neighbors.base.KNeighborsMixin` that will be used to
         find the k_neighbors.
+        By default, it will be a 3-NN.
 
-    n_neighbors_ver3 : int or object, default=3
+    n_neighbors_ver3 : int or estimator object, default=3
         If ``int``, NearMiss-3 algorithm start by a phase of re-sampling. This
         parameter correspond to the number of neighbours selected create the
         subset in which the selection will be performed.  If object, an
         estimator that inherits from
-        :class:`sklearn.neighbors.base.KNeighborsMixin` that will be used to
+        :class:`~sklearn.neighbors.base.KNeighborsMixin` that will be used to
         find the k_neighbors.
+        By default, it will be a 3-NN.
 
     {n_jobs}
 
     Attributes
     ----------
-    sample_indices_ : ndarray of shape (n_new_samples)
+    sampling_strategy_ : dict
+        Dictionary containing the information to sample the dataset. The keys
+        corresponds to the class labels from which to sample and the values
+        are the number of samples to sample.
+
+    nn_ : estimator object
+        Validated K-nearest Neighbours object created from `n_neighbors` parameter.
+
+    sample_indices_ : ndarray of shape (n_new_samples,)
         Indices of the samples selected.
 
         .. versionadded:: 0.4
 
+    n_features_in_ : int
+        Number of features in the input dataset.
+
+        .. versionadded:: 0.9
+
     See Also
     --------
     RandomUnderSampler : Random undersample the dataset.
@@ -78,7 +93,6 @@ class NearMiss(BaseUnderSampler):
 
     Examples
     --------
-
     >>> from collections import Counter
     >>> from sklearn.datasets import make_classification
     >>> from imblearn.under_sampling import \
@@ -143,13 +157,10 @@ NearMiss # doctest: +NORMALIZE_WHITESPACE
         """
 
         # Compute the distance considering the farthest neighbour
-        dist_avg_vec = np.sum(dist_vec[:, -self.nn_.n_neighbors:], axis=1)
+        dist_avg_vec = np.sum(dist_vec[:, -self.nn_.n_neighbors :], axis=1)
 
         target_class_indices = np.flatnonzero(y == key)
-        if (
-            dist_vec.shape[0]
-            != _safe_indexing(X, target_class_indices).shape[0]
-        ):
+        if dist_vec.shape[0] != _safe_indexing(X, target_class_indices).shape[0]:
             raise RuntimeError(
                 "The samples to be selected do not correspond"
                 " to the distance matrix given. Ensure that"
@@ -198,8 +209,7 @@ NearMiss # doctest: +NORMALIZE_WHITESPACE
 
         if self.version not in (1, 2, 3):
             raise ValueError(
-                "Parameter `version` must be 1, 2 or 3, got"
-                " {}".format(self.version)
+                f"Parameter `version` must be 1, 2 or 3, got {self.version}"
             )
 
     def _fit_resample(self, X, y):
@@ -250,10 +260,8 @@ NearMiss # doctest: +NORMALIZE_WHITESPACE
                         _safe_indexing(X, minority_class_indices)
                     )
                     idx_vec_farthest = np.unique(idx_vec.reshape(-1))
-                    X_class_selected = _safe_indexing(
-                        X_class, idx_vec_farthest)
-                    y_class_selected = _safe_indexing(
-                        y_class, idx_vec_farthest)
+                    X_class_selected = _safe_indexing(X_class, idx_vec_farthest)
+                    y_class_selected = _safe_indexing(y_class, idx_vec_farthest)
 
                     dist_vec, idx_vec = self.nn_.kneighbors(
                         X_class_selected, n_neighbors=self.nn_.n_neighbors
@@ -284,6 +292,7 @@ NearMiss # doctest: +NORMALIZE_WHITESPACE
 
         return _safe_indexing(X, idx_under), _safe_indexing(y, idx_under)
 
+    # fmt: off
     def _more_tags(self):
         return {
             "sample_indices": True,
@@ -292,3 +301,4 @@ NearMiss # doctest: +NORMALIZE_WHITESPACE
                 "Fails for NearMiss-3 with less samples than expected"
             }
         }
+    # fmt: on
