@@ -6,6 +6,7 @@
 
 import inspect
 import pkgutil
+import warnings
 from contextlib import contextmanager
 from importlib import import_module
 from re import compile
@@ -18,7 +19,9 @@ from sklearn.base import BaseEstimator
 from sklearn.utils._testing import ignore_warnings
 
 
-def all_estimators(type_filter=None,):
+def all_estimators(
+    type_filter=None,
+):
     """Get a list of all estimators from imblearn.
 
     This function crawls the module and gets all classes that inherit
@@ -29,7 +32,7 @@ def all_estimators(type_filter=None,):
 
     Parameters
     ----------
-    type_filter : string, list of string, or None, default=None
+    type_filter : str, list of str, or None, default=None
         Which kind of estimators should be returned. If None, no
         filter is applied and all estimators are returned.  Possible
         values are 'sampler' to get estimators only of these specific
@@ -41,7 +44,6 @@ def all_estimators(type_filter=None,):
     estimators : list of tuples
         List of (name, class), where ``name`` is the class name as string
         and ``class`` is the actual type of the class.
-
     """
     from ..base import SamplerMixin
 
@@ -59,15 +61,16 @@ def all_estimators(type_filter=None,):
     # packages
     with ignore_warnings(category=FutureWarning):
         for importer, modname, ispkg in pkgutil.walk_packages(
-                path=[root], prefix='imblearn.'):
+            path=[root], prefix="imblearn."
+        ):
             mod_parts = modname.split(".")
-            if (any(part in modules_to_ignore for part in mod_parts)
-                    or '._' in modname):
+            if any(part in modules_to_ignore for part in mod_parts) or "._" in modname:
                 continue
             module = import_module(modname)
             classes = inspect.getmembers(module, inspect.isclass)
-            classes = [(name, est_cls) for name, est_cls in classes
-                       if not name.startswith("_")]
+            classes = [
+                (name, est_cls) for name, est_cls in classes if not name.startswith("_")
+            ]
 
             all_classes.extend(classes)
 
@@ -113,7 +116,11 @@ def all_estimators(type_filter=None,):
 
 @contextmanager
 def warns(expected_warning, match=None):
-    r"""Assert that a warning is raised with an optional matching pattern
+    r"""Assert that a warning is raised with an optional matching pattern.
+
+    .. deprecated:: 0.8
+       This function is deprecated in 0.8 and will be removed in 0.10.
+       Use `pytest.warns()` instead.
 
     Assert that a code block/function call warns ``expected_warning``
     and raise a failure exception otherwise. It can be used within a context
@@ -127,19 +134,22 @@ def warns(expected_warning, match=None):
     match : regex str or None, optional
         The pattern to be matched. By default, no check is done.
 
-    Returns
-    -------
-    None
+    Yields
+    ------
+    Nothing.
 
     Examples
     --------
-
     >>> import warnings
     >>> from imblearn.utils.testing import warns
     >>> with warns(UserWarning, match=r'must be \d+$'):
     ...     warnings.warn("value must be 42", UserWarning)
-
     """
+    warnings.warn(
+        "The warns function is deprecated in 0.8 and will be removed in 0.10. "
+        "Use pytest.warns() instead."
+    )
+
     with _warns(expected_warning) as record:
         yield
 
